@@ -20,8 +20,9 @@ def image_to_tensor(image: Image) -> np.ndarray:
         Preprocessed numpy array.
     """
     image = image.convert('RGB')
-    tensor = np.asarray(image, dtype=np.float16)
+    tensor = np.asarray(image)
     tensor = crop_and_resize(tensor, 331)
     tensor = (tensor / 255.0 - 0.5) * 2.0
+    tensor = tensor.astype(np.float32)
     assert tensor.shape == (331, 331, 3)
     return tensor
